/* eslint import/no-extraneous-dependencies: ["error", {"peerDependencies": true}] */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import getStyleName from '../../utils/getStyleName';
import styles from './Header.scss';

const itemType = PropTypes.shape({
  title: PropTypes.string.isRequired,
  url: PropTypes.string.isRequired,
});

const style = {
  narrowedPopup: {
    width: '120px',
    height: 'auto',
    overflow: 'visible',
  },
  narrowedList: {
    height: 'auto',
  },
};

function renderStaticList(list, className, wrapperStyle, listTitle) {
  const content = list.map(({ url, title, icon }, id) => (
    <a
      key={id} // eslint-disable-line react/no-array-index-key
      href={url}
      className={icon ? getStyleName(styles, `icon-${icon}`) : null}
      title={title}
    >
      {title}
    </a>
  ));

  return (
    <nav className={className} style={wrapperStyle || {}}>
      {listTitle && <h5>{listTitle}</h5>}
      {content}
    </nav>
  );
}

export default class SubMenu extends Component {
  static propTypes = {
    // ownProps
    /* tab label */
    title: PropTypes.string.isRequired,
    url: PropTypes.string.isRequired,
    className: PropTypes.string,
    /* Menu */
    leftList: PropTypes.arrayOf(itemType),
    leftListTitle: PropTypes.string,
    rightList: PropTypes.arrayOf(itemType),
    rightListTitle: PropTypes.string,
    isNew: PropTypes.bool,
  };

  static defaultProps = {
    className: '',
    leftList: undefined,
    leftListTitle: undefined,
    rightList: undefined,
    rightListTitle: undefined,
    isNew: false,
  };

  renderPopupMenu() {
    const { leftList, leftListTitle, rightList, rightListTitle } = this.props;

    if (!leftList && !rightList) {
      // no left and no right, => no popup menu
      return null;
    }

    return (
      <div
        className={classNames(getStyleName(styles, 'popup'), 'theme-popup')}
        style={(!rightList && style.narrowedPopup) || {}}
      >
        {leftList &&
          renderStaticList(
            leftList,
            classNames(getStyleName(styles, 'link-wrapper'), 'theme-link-wrapper'),
            !rightList && style.narrowedList,
            leftListTitle
          )}
        {rightList &&
          renderStaticList(
            rightList,
            classNames(getStyleName(styles, 'news-list'), 'theme-news-list'),
            undefined,
            rightListTitle
          )}
      </div>
    );
  }

  render() {
    const { url, title, className, leftList, isNew } = this.props;

    return (
      <div className={className} onMouseEnter={this.loadNewsByCat}>
        {url.length ? (
          <a
            href={url}
            className={classNames(getStyleName(styles, 'submenu-title'), { [getStyleName(styles, 'is-new')]: isNew })}
          >
            {title}
            {leftList && <span className={getStyleName(styles, 'with-arrow')} />}
          </a>
        ) : (
          <span className={getStyleName(styles, 'submenu-title')}>
            {title}
            {leftList && <span className={getStyleName(styles, 'with-arrow')} />}
          </span>
        )}
        {this.renderPopupMenu()}
      </div>
    );
  }
}
