import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';

import styles from './ScrollingQuote.scss';

const cx = classNames.bind(styles);

class ScrollingQuote extends React.Component {
  static propTypes = {
    inverted: PropTypes.bool,
    speed: PropTypes.number,
    quotes: PropTypes.arrayOf(
      PropTypes.shape({
        name: PropTypes.string.isRequired,
        value: PropTypes.string.isRequired,
        netChange: PropTypes.string.isRequired,
        changeInPercentage: PropTypes.string.isRequired,
      })
    ),
  };

  static defaultProps = {
    inverted: false,
    speed: 1,
    quotes: [],
  };

  componentDidMount() {
    this.scrollerElementWidth = this.getScrollerElementWidth();
    this.wrapperElementWidth = this.getWrapperElementWidth();
    this.shift = this.wrapperElementWidth;

    this.startScroll();

    if (window && window.addEventListener) {
      window.addEventListener('resize', this.resizeCallback);
    }
  }

  componentWillUnmount() {
    this.stopScroll();

    if (window && window.removeEventListener) {
      window.removeEventListener('resize', this.resizeCallback);
    }
  }

  getScrollerElementWidth = () => this.scrollerElement.getBoundingClientRect().width;

  getWrapperElementWidth = () => this.scrollerElement.parentNode.getBoundingClientRect().width;

  setScrollerElement = element => {
    this.scrollerElement = element;
  };

  getShift = shift => {
    if (shift < -this.scrollerElementWidth) {
      return this.wrapperElementWidth;
    }

    return shift - this.props.speed;
  };

  resizeCallback = () => {
    this.wrapperElementWidth = this.getWrapperElementWidth();
  };

  scroll = () => {
    this.shift = this.getShift(this.shift);
    this.scrollerElement.style.transform = `translateX(${this.shift}px)`;

    if (window && window.requestAnimationFrame) {
      this.rafId = window.requestAnimationFrame(this.scroll);
    }
  };

  startScroll = () => {
    if (window && window.requestAnimationFrame) {
      this.rafId = window.requestAnimationFrame(this.scroll);
    }
  };

  stopScroll = () => {
    if (window && window.cancelAnimationFrame) {
      window.cancelAnimationFrame(this.rafId);
    }
  };

  render() {
    const { inverted, quotes } = this.props;

    return (
      <div className={cx('wrapper', { inverted })} onMouseEnter={this.stopScroll} onMouseLeave={this.startScroll}>
        <div className={cx('scroller')} ref={this.setScrollerElement}>
          {quotes.map(({ name, value, netChange, changeInPercentage }) => {
            const sign = netChange[0];
            const positive = sign === '+';
            const negative = sign === '-';

            return (
              <span key={name} className={cx('quote', { positive, negative })}>
                <span className={cx('name')}>{name}</span>
                <span>{value}</span>
                <span className={cx('mark')} />
                <span className={cx('change')}>{netChange}</span>
                <span className={cx('change')}>{changeInPercentage}</span>
              </span>
            );
          })}
        </div>
      </div>
    );
  }
}

export default ScrollingQuote;
